@@ -25,7 +25,7 @@ default_keys_to_ignore = [
 ]
 
 
-def different_ods(ods1, ods2, ignore_type=False, ignore_empty=False, ignore_keys=[], ignore_default_keys=True):
+def different_ods(ods1, ods2, ignore_type=False, ignore_empty=False, ignore_keys=[], ignore_default_keys=True, rtol=1.0e-5, atol=1.0e-8):
     """
     Checks if two ODSs have any difference and returns the string with the cause of the different
 
@@ -42,6 +42,10 @@ def different_ods(ods1, ods2, ignore_type=False, ignore_empty=False, ignore_keys
     :param ignore_default_keys: ignores the following keys from the comparison
                             %s
 
+    rtol : The relative tolerance parameter
+
+    atol : The absolute tolerance parameter
+
     :return: string with reason for difference, or False otherwise
     """
     from omas import ODS, CodeParameters
@@ -86,7 +90,9 @@ def different_ods(ods1, ods2, ignore_type=False, ignore_empty=False, ignore_keys
                 s2 = v2.shape
                 if s1 != s2:
                     differences.append(f'DIFF: `{k}` differ in shape: {s1} vs {s2}')
-                elif not numpy.allclose(v1, v2, equal_nan=True) or not numpy.allclose(d1, d2, equal_nan=True):
+                elif not numpy.allclose(v1, v2, equal_nan=True, atol=atol, rtol=rtol) or not numpy.allclose(
+                    d1, d2, equal_nan=True, atol=atol, rtol=rtol
+                ):
                     differences.append(f'DIFF: `{k}` differ in value')
             else:
                 v1 = nominal_values(ods1[k])
@@ -95,7 +101,7 @@ def different_ods(ods1, ods2, ignore_type=False, ignore_empty=False, ignore_keys
                 s2 = v2.shape
                 if v1.shape != v2.shape:
                     differences.append(f'DIFF: `{k}` differ in shape: {s1} vs {s2}')
-                elif not numpy.allclose(ods1[k], ods2[k], equal_nan=True):
+                elif not numpy.allclose(ods1[k], ods2[k], equal_nan=True, atol=atol, rtol=rtol):
                     differences.append(f'DIFF: `{k}` differ in value')
         except Exception as _excp:
             raise Exception(f'Error comparing {k}: ' + repr(_excp))
@@ -109,7 +115,7 @@ different_ods.__doc__ = different_ods.__doc__ % '\n                            '
 
 
 def different_ods_attrs(ods1, ods2, attrs=None, verbose=False):
-    '''
+    """
     Checks if two ODSs have any difference in their attributes
 
     :param ods1: first ods to check
@@ -121,7 +127,7 @@ def different_ods_attrs(ods1, ods2, attrs=None, verbose=False):
     :param verbose: print differences to stdout
 
     :return: dictionary with list of attriibutes that have differences, or False otherwise
-    '''
+    """
 
     if isinstance(attrs, str):
         attrs = [attrs]
@@ -168,6 +174,9 @@ def different_ods_attrs(ods1, ods2, attrs=None, verbose=False):
 # --------------------------
 # general utility functions
 # --------------------------
+_streams = {'DEBUG': sys.stderr, 'STDERR': sys.stderr}
+
+
 def printd(*objects, **kw):
     """
     debug print
@@ -188,10 +197,11 @@ def printd(*objects, **kw):
         dump = True
         topic_selected = re.sub('_dump$', '', topic_selected)
     if topic_selected and (topic_selected == '*' or topic_selected in topic or '*' in topic):
-        if eval(os.environ.get('OMAS_DEBUG_STDOUT', '1')):
-            print(*objects, **kw)
+        if eval(os.environ.get('OMAS_DEBUG_STDOUT', '0')):
+            kw.setdefault('file', sys.stdout)
         else:
-            printe(*objects, **kw)
+            kw.setdefault('file', _streams['DEBUG'])
+        print(*objects, **kw)
         if dump:
             fb = StringIO()
             print(*objects[1:], file=fb)
@@ -204,7 +214,7 @@ def printe(*objects, **kw):
     """
     print to stderr
     """
-    kw['file'] = sys.stderr
+    kw['file'] = _streams['STDERR']
     print(*objects, **kw)
 
 
@@ -767,7 +777,7 @@ def load_structure(filename, imas_version):
 
 
 def imas_structure(imas_version, location):
-    '''
+    """
     Returns a dictionary with the IMAS structure given a location
 
     :param imas_version: imas version
@@ -775,7 +785,7 @@ def imas_structure(imas_version, location):
     :param location: path in OMAS format
 
     :return: dictionary as loaded by load_structure() at location
-    '''
+    """
     if imas_version not in _ods_structure_cache:
         _ods_structure_cache[imas_version] = {}
     ulocation = o2u(location)
@@ -854,15 +864,20 @@ def omas_global_quantities(imas_version=omas_rcparams['default_imas_version']):
     return _global_quantities[imas_version]
 
 
-try:
-    import pyximport
-
-    pyximport.install(language_level=3)
-    from .omas_cython import *
-except Exception as _excp:
-    warnings.warn('omas cython failed: ' + str(_excp))
+# only attempt cython if user owns this copy of omas
+if os.environ['USER'] != pwd.getpwuid(os.stat(__file__).st_uid).pw_name:
     with open(os.path.split(__file__)[0] + os.sep + 'omas_cython.pyx', 'r') as f:
         exec(f.read(), globals())
+else:
+    try:
+        import pyximport
+
+        pyximport.install(language_level=3)
+        from .omas_cython import *
+    except Exception as _excp:
+        warnings.warn('omas cython failed: ' + str(_excp))
+        with open(os.path.split(__file__)[0] + os.sep + 'omas_cython.pyx', 'r') as f:
+            exec(f.read(), globals())
 
 
 def l2ut(path):
