@@ -243,13 +243,7 @@ class TestOmasCore(UnittestCaseOmas):
         assert sizes[None] == sizes['time'], 'sample equilibrium and core_profiles should be homogeneous'
 
         ods.sample_pf_active()
-        try:
-            DS = ods.dataset(homogeneous='full')
-            raise AssertionError(
-                'sample pf_active data should not be able to collect across channels because their time arrays are not homogeneous'
-            )
-        except ValueError:
-            pass
+        DS = ods.dataset(homogeneous='full')
 
     def test_time(self):
         # test generation of a sample ods
@@ -459,7 +453,7 @@ class TestOmasCore(UnittestCaseOmas):
 
     def test_codeparameters(self):
         ods = ODS()
-        ods['equilibrium.code.parameters'] = CodeParameters(imas_json_dir + '/../samples/input_gray.xml')
+        ods['equilibrium.code.parameters'] = CodeParameters(omas_dir + 'samples/input_gray.xml')
 
         tmp = {}
         tmp.update(ods['equilibrium.code.parameters'])
@@ -484,7 +478,7 @@ class TestOmasCore(UnittestCaseOmas):
         assert isinstance(ods['equilibrium.code.parameters'], CodeParameters)
 
         # test loading CodeParameters from a json
-        ods = ODS().load(imas_json_dir + '/../samples/ods_w_code_parameters.json')
+        ods = ODS().load(omas_dir + 'samples/ods_w_code_parameters.json')
         # test traversing ODS and code parameters with OMAS syntax
         assert ods['ec_launchers.code.parameters.launcher.0.mharm'] == 2
         # test that sub-tree elements of code parameters are also of CodeParameters class
